@@ -713,11 +713,11 @@ setMethod(
 .rstan_max_treedepth <- function(x) {
   cntrl <- .stan_args(x, "control")
   if (is.null(cntrl)) {
-    max_td <- 11
+    max_td <- 10
   } else {
     max_td <- cntrl$max_treedepth
     if (is.null(max_td))
-      max_td <- 11
+      max_td <- 10
   }
   max_td
 }
@@ -867,3 +867,52 @@ setMethod(
   
   pp_check_plots
 }
+
+
+# as.shinystan (CmdStanMCMC) -----------------------------------------------
+setOldClass("CmdStanMCMC")
+#' @describeIn as.shinystan Create a \code{shinystan} object from a 
+#'   \code{CmdStanMCMC} object (\pkg{cmdstanr}).
+#' 
+setMethod(
+  "as.shinystan",
+  signature = "CmdStanMCMC",
+  definition = function(X,
+                        pars = NULL,
+                        model_name = NULL,
+                        note = NULL,
+                        ...) {
+    check_suggests("cmdstanr")
+    check_suggests("posterior")
+    if (is.null(model_name)) {
+      model_name <- X$runset$model_name()
+    }
+    
+    if (X$metadata()$save_warmup == 0) {
+      draws <- unclass(X$draws(pars))
+      sampler_diagnostics <- X$sampler_diagnostics()
+      n_warmup <- 0
+    } else {
+      draws <- unclass(X$draws(pars, inc_warmup = TRUE))
+      sampler_diagnostics <- X$sampler_diagnostics(inc_warmup = TRUE)
+      n_warmup <- X$metadata()$iter_warmup
+    }
+    
+    sampler_params <- list()
+    for (j in seq_len(dim(sampler_diagnostics)[2])) {
+      sampler_params[[j]] <- posterior::as_draws_matrix(sampler_diagnostics[, j ,])
+    }
+    
+    as.shinystan(
+      draws,
+      model_name = model_name,
+      warmup = n_warmup,
+      param_dims = X$metadata()$stan_variable_dims,
+      model_code = NULL,
+      note = note,
+      sampler_params = sampler_params, 
+      algorithm = "NUTS",
+      max_treedepth = X$metadata()$max_treedepth
+    )
+  }
+)
